#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MINUS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MINUS_HPP_INCLUDED

#include <boost/simd/operator/include/functions/minus.hpp>

#endif
